@@ -13,6 +13,12 @@ class Commit:
         pass
 
 
+class Git:
+
+    def commits(self):
+        pass
+
+
 class Changelog:
 
     def parse(self):
@@ -25,6 +31,7 @@ class Changelog:
 class BaseChangelog:
 
     changelog = Changelog()
+    version_control = Git()
 
     @property
     def regex(self):
